@@ -4,7 +4,7 @@ import yappi
 
 
 def generate_func(func_name, code):
-    code = """def {0}(*args, **kwargs): {1}""".format(func_name, code)
+    code = f"""def {func_name}(*args, **kwargs): {code}"""
     exec(code, globals(), locals())
     func = locals()[func_name]
     globals()[func.__name__] = func
@@ -20,9 +20,9 @@ top_level_funcs = []
 
 # todo: generate functions that are N stack depth
 for i in range(FUNC_COUNT):
-    func = generate_func('func_{0}'.format(i), "pass")
+    func = generate_func(f'func_{i}', "pass")
     for k in range(MAX_STACK_DEPTH):
-        func = generate_func('func_{0}_{1}'.format(i, k), func.__name__ + '()')
+        func = generate_func(f'func_{i}_{k}', func.__name__ + '()')
     top_level_funcs.append(func)
 
 #print(globals())
@@ -31,5 +31,5 @@ t0 = time.time()
 #yappi.start()
 for f in top_level_funcs:
     f(i)
-print("Elapsed %0.6f secs" % (time.time() - t0))
+print(f"Elapsed {time.time() - t0:0.6f} secs")
 #yappi.get_func_stats().print_all()
