@@ -13,9 +13,7 @@
 #error "Yappi requires long longs!"
 #endif
 
-#ifdef IS_PY3K
 #include "bytesobject.h"
-#endif
 #include "frameobject.h"
 #include "callstack.h"
 #include "hashtab.h"
@@ -27,9 +25,7 @@
 
 #define SUPPRESS_WARNING(a) (void)a
 
-#ifdef IS_PY3K
 PyDoc_STRVAR(_yappi__doc__, "Yet Another Python Profiler");
-#endif
 
 // linked list for holding callee/caller info in the pit
 // we need to record the timing data on the pairs (parent, child)
@@ -178,17 +174,10 @@ static _ctx_type_t ctx_type = NATIVE_THREAD;
 // defines
 #define UNINITIALIZED_STRING_VAL "N/A"
 
-#ifdef IS_PY3K // string formatting helper functions compatible with with both 2.x and 3.x
 #define PyStr_AS_CSTRING(s) PyUnicode_AsUTF8(s)
 #define PyStr_Check(s) PyUnicode_Check(s)
 #define PyStr_FromString(s) PyUnicode_FromString(s)
 #define PyStr_FromFormatV(fmt, vargs) PyUnicode_FromFormatV(fmt, vargs)
-#else // < Py3x
-#define PyStr_AS_CSTRING(s) PyString_AS_STRING(s)
-#define PyStr_Check(s) PyString_Check(s)
-#define PyStr_FromString(s) PyString_FromString(s)
-#define PyStr_FromFormatV(fmt, vargs) PyString_FromFormatV(fmt, vargs)
-#endif
 
 #define PyLong_AsVoidPtr (uintptr_t)PyLong_AsVoidPtr
  
@@ -202,7 +191,7 @@ static int _pitenumdel(_hitem *item, void *arg);
 
 static PyCodeObject *
 FRAME2CODE(PyFrameObject *frame) {
-#if PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION >= 10
+#if PY_VERSION_HEX >= 0x030A0000 // Python 3.10+
     return PyFrame_GetCode(frame);
 #else
     return frame->f_code;
@@ -224,7 +213,7 @@ static void _DebugPrintObjects(unsigned int arg_count, ...)
 
 int 
 IS_SUSPENDED(PyFrameObject *frame) {
-#if PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION == 11
+#if PY_VERSION_HEX >= 0x030B0000  // Python 3.11+
     PyGenObject *gen = (PyGenObject *)PyFrame_GetGenerator(frame);
     if (gen == NULL) {
         return 0;
@@ -234,7 +223,7 @@ IS_SUSPENDED(PyFrameObject *frame) {
     // TODO: Remove these after 3.12 make necessary public APIs.
     // See https://discuss.python.org/t/python-3-11-frame-structure-and-various-changes/17895
     return gen->gi_frame_state == -1;
-#elif PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION == 10
+#elif PY_VERSION_HEX >= 0x030A0000 // Python 3.10+
     return (frame->f_state == FRAME_SUSPENDED);
 #else
     return (frame->f_stacktop != NULL);
@@ -243,19 +232,9 @@ IS_SUSPENDED(PyFrameObject *frame) {
 
 int IS_ASYNC(PyFrameObject *frame)
 {
-    int result = 0;
-
-#if defined(IS_PY3K) 
-#if PY_MINOR_VERSION >= 4
-    result = FRAME2CODE(frame)->co_flags & CO_COROUTINE || 
-        FRAME2CODE(frame)->co_flags & CO_ITERABLE_COROUTINE;
-#endif
-#if PY_MINOR_VERSION >= 6
-    result = result || FRAME2CODE(frame)->co_flags & CO_ASYNC_GENERATOR;
-#endif
-#endif
-
-    return result;
+    return FRAME2CODE(frame)->co_flags & CO_COROUTINE ||
+        FRAME2CODE(frame)->co_flags & CO_ITERABLE_COROUTINE ||
+        FRAME2CODE(frame)->co_flags & CO_ASYNC_GENERATOR;
 }
 
 static PyObject *
@@ -644,7 +623,7 @@ _ccode2pit(void *cco, uintptr_t current_tag)
 }
 
 static PyObject *_get_locals(PyFrameObject *fobj) {
-#if PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION >= 10
+#if PY_VERSION_HEX >= 0x030A0000 // Python 3.10+
     return PyEval_GetLocals();
 #else
     PyFrame_FastToLocals(fobj);
@@ -691,7 +670,7 @@ _code2pit(PyFrameObject *fobj, uintptr_t current_tag)
     if (cobj->co_argcount) {
         // There has been a lot going on with `co_varnames`, but finally in 
         // 3.11.0rc1, it is added as a public API
-#if PY_MAJOR_VERSION >= 3 && PY_MINOR_VERSION == 11
+#if PY_VERSION_HEX >= 0x030B0000 // Python 3.11+
         co_varnames = PyCode_GetVarnames(cobj);
 #else
         co_varnames = cobj->co_varnames;
@@ -709,8 +688,12 @@ _code2pit(PyFrameObject *fobj, uintptr_t current_tag)
                         if (class_name) {
                             pit->name = PyStr_FromFormat("%s.%s", PyStr_AS_CSTRING(class_name), PyStr_AS_CSTRING(cobj->co_name));
                             Py_DECREF(class_name);
+                        } else {
+                            PyErr_Clear();
                         }
                         Py_DECREF(class_obj);
+                    } else {
+                        PyErr_Clear();
                     }
                 }
             }
@@ -1305,7 +1288,9 @@ _resume_greenlet_ctx(_ctx *ctx)
 static void 
 _eval_setprofile(PyThreadState *ts)
 {
-#if PY_VERSION_HEX > 0x030b0000
+#if PY_VERSION_HEX > 0x030c0000
+    PyEval_SetProfileAllThreads(_yapp_callback, NULL);
+#elif PY_VERSION_HEX > 0x030b0000
     _PyEval_SetProfile(ts, _yapp_callback, NULL);
 #elif PY_VERSION_HEX < 0x030a00b1
     ts->use_tracing = 1;
@@ -1319,7 +1304,9 @@ _eval_setprofile(PyThreadState *ts)
 static void
 _eval_unsetprofile(PyThreadState *ts)
 {
-#if PY_VERSION_HEX > 0x030b0000
+#if PY_VERSION_HEX > 0x030c0000
+    PyEval_SetProfileAllThreads(NULL, NULL);
+#elif PY_VERSION_HEX > 0x030b0000
     _PyEval_SetProfile(ts, NULL, NULL);
 #elif PY_VERSION_HEX < 0x030a00b1
     ts->use_tracing = 0;
@@ -2191,7 +2178,6 @@ static PyMethodDef yappi_methods[] = {
     {NULL, NULL, 0, NULL}      /* sentinel */
 };
 
-#ifdef IS_PY3K
 static struct PyModuleDef _yappi_module = {
     PyModuleDef_HEAD_INIT,
     "_yappi",
@@ -2203,26 +2189,15 @@ static struct PyModuleDef _yappi_module = {
     NULL,
     NULL
 };
-#endif
 
 PyMODINIT_FUNC
-#ifdef IS_PY3K
 PyInit__yappi(void)
-#else
-init_yappi(void)
-#endif
 {
     PyObject *m, *d;
 
-#ifdef IS_PY3K
     m = PyModule_Create(&_yappi_module);
     if (m == NULL)
         return NULL;
-#else
-    m = Py_InitModule("_yappi",  yappi_methods);
-    if (m == NULL)
-        return;
-#endif
 
     d = PyModule_GetDict(m);
     YappiProfileError = PyErr_NewException("_yappi.error", NULL, NULL);
@@ -2242,14 +2217,8 @@ init_yappi(void)
 
     if (!_init_profiler()) {
         PyErr_SetString(YappiProfileError, "profiler cannot be initialized.");
-#ifdef IS_PY3K
         return NULL;
-#else
-        return;
-#endif
     }
 
-#ifdef IS_PY3K
     return m;
-#endif
 }
